# tomoAO
Python package with atmospheric tomography generic functions and tools

## Installation

1. Install OOPAO
    ```sh
    git clone https://github.com/cheritier/OOPAO
    pip install -e 'path to OOPAO'
    ```

2. Install cupy according to your cuda version (Optional)
    ```sh
    pip install cupy-cuda11x
    ```
    ```sh
    pip install cupy-cuda12x
    ```

3. Install tomoAO via pip
    ```sh
    pip install tomoAO
    ```

    Or clone the repository
    ```sh
    git clone https://github.com/SpaceODT/tomoAO
    pip install -e 'path to tomoAO'
    ```
    



